@@ -34,21 +34,16 @@ from gqrxHamlib import gqrxHamlibGUI
 class startControl(QThread):
     reportErr = QtCore.pyqtSignal(str, str)
     
-    def __init__(self, control, oneoff, gqrxIPv, gqrxPortv, hamlibIPv, hamlibPortv, fldigiIPv, fldigiPortv, fldigiv, modev, ifModev, ifFreqv):
+    def __init__(self, control, oneoff, gqrxIPv, gqrxPortv, hamlibIPv, hamlibPortv,  modev, ifModev, ifFreqv):
         QThread.__init__(self)
         self.control = control
         self.oneoff = oneoff
-        self.fldigi_option_set = 1
         self.gqrxIPv = gqrxIPv
         self.gqrxPortv = gqrxPortv
         self.hamlibIPv = hamlibIPv
         self.hamlibPortv = hamlibPortv
-        self.fldigiIPv = fldigiIPv
-        self.fldigiPortv = fldigiPortv
-        self.fldigiv = fldigiv
         self.modev = modev
         TCP_IP = '127.0.0.1'
-        FLDIGI_PORT = 7362
         
         self.ifFreqv = ifFreqv
         self.ifModev = ifModev
@@ -62,20 +57,13 @@ class startControl(QThread):
     def run(self):    
         HAMLIB_PORT = 4532
         GQRX_PORT = 7356
-        FLRIG_PORT = 7362
         sockGqrx = 0
         sockHamlib = 0
         #self.setupUi(self)
-        if self.fldigiv == 'Y':
-            endpoint = 'flrig'
-            RIG_PORT = FLRIG_PORT
-            TCP_IP = self.fldigiIPv
-#           self.server = xmlrpc.client.ServerProxy('http://{}:{}/'.format(TCP_IP, RIG_PORT))
-        else:
-            endpoint = 'hamlib'
-            RIG_PORT = HAMLIB_PORT
-            TCP_IP = self.hamlibIPv
-            sockHamlib = socket.create_connection((TCP_IP, HAMLIB_PORT))
+        endpoint = 'hamlib'
+        RIG_PORT = HAMLIB_PORT
+        TCP_IP = self.hamlibIPv
+        sockHamlib = socket.create_connection((TCP_IP, HAMLIB_PORT))
             #sockHamlib = socket.socket(socket.AF_INET, socket.SOCK_STREAM) 
             # Bind the socket to the port
             #server_address1 = (TCP_IP, HAMLIB_PORT)
@@ -287,7 +275,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         global rc 
         rc = ''
         
-        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.fldigiIPv, self.fldigiPortv, self.fldigiv, self.modev, self.ifModev, self.ifFreqv)
+        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.modev, self.ifModev, self.ifFreqv)
         self.controlThread.reportErr.connect(self.reportErrMsg)
         # At this point we want to allow user to stop/terminate the thread
         # so we enable that button
@@ -332,7 +320,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         oneoff = False
         self.controlThread.terminate()
         self.errorMsg.setText('')
-        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.fldigiIPv, self.fldigiPortv, self.fldigiv, self.modev, self.ifModev, self.ifFreqv)
+        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.modev, self.ifModev, self.ifFreqv)
         self.controlThread.reportErr.connect(self.reportErrMsg)
         self.controlThread.start()
         
@@ -348,7 +336,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         oneoff = False
         self.controlThread.terminate()
         self.errorMsg.setText('')
-        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.fldigiIPv, self.fldigiPortv, self.fldigiv, self.modev, self.ifModev, self.ifFreqv)
+        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.modev, self.ifModev, self.ifFreqv)
         self.controlThread.reportErr.connect(self.reportErrMsg)
         self.controlThread.start()
     
@@ -364,7 +352,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         oneoff = False
         self.controlThread.terminate()
         self.errorMsg.setText('')
-        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.fldigiIPv, self.fldigiPortv, self.fldigiv, self.modev, self.ifModev, self.ifFreqv)
+        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.modev, self.ifModev, self.ifFreqv)
         self.controlThread.reportErr.connect(self.reportErrMsg)
         self.controlThread.start()
               
@@ -380,7 +368,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         oneoff = True
         self.controlThread.terminate()
         self.errorMsg.setText('')
-        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.fldigiIPv, self.fldigiPortv, self.fldigiv, self.modev, self.ifModev, self.ifFreqv)
+        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.modev, self.ifModev, self.ifFreqv)
         self.controlThread.reportErr.connect(self.reportErrMsg)
         self.controlThread.start()
         self.pushButton_6.setStyleSheet("background-color: green")
@@ -398,7 +386,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         oneoff = True
         self.controlThread.terminate()
         self.errorMsg.setText('')
-        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.fldigiIPv, self.fldigiPortv, self.fldigiv, self.modev, self.ifModev, self.ifFreqv)
+        self.controlThread = startControl(self.control, oneoff, self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.modev, self.ifModev, self.ifFreqv)
         self.controlThread.reportErr.connect(self.reportErrMsg)
         self.controlThread.start()
         self.pushButton_4.setStyleSheet("background-color: green")
@@ -418,29 +406,21 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         # handle upgrade from 2.5 to 2.6 where there are two additional parameters for IF panaadaptor functionality
         countitems = len(configLine.split(','))
         if countitems == 8:
-            self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.fldigiIPv, self.fldigiPortv, self.fldigiv, self.modev = configLine.split(',')
+            self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.modev = configLine.split(',')
             self.ifModev = 'N'
             self.ifFreqv = str(0)
             cf.close()
             cf = open(homedir + '/.config/.gqrxHamlib.config', 'w')
-            configLine = self.gqrxIPv+','+self.gqrxPortv+','+self.hamlibIPv+','+self.hamlibPortv+','+self.fldigiIPv+','+self.fldigiPortv+','+self.fldigiv+','+self.modev+','+self.ifModev+','+self.ifFreqv
+            configLine = self.gqrxIPv+','+self.gqrxPortv+','+self.hamlibIPv+','+self.hamlibPortv+','+self.modev+','+self.ifModev+','+self.ifFreqv
             cf.write(configLine)
             cf.close()
         else:
-            self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.fldigiIPv, self.fldigiPortv, self.fldigiv, self.modev, self.ifModev, self.ifFreqv = configLine.split(',')
+            self.gqrxIPv, self.gqrxPortv, self.hamlibIPv, self.hamlibPortv, self.modev, self.ifModev, self.ifFreqv = configLine.split(',')
         self.gqrxIP.setText(self.gqrxIPv)
         self.gqrxPort.setText(self.gqrxPortv)
         self.hamlibIP.setText(self.hamlibIPv)
         self.hamlibPort.setText(self.hamlibPortv)
-        self.fldigiIP.setText(self.fldigiIPv)
-        self.fldigiPort.setText(self.fldigiPortv)
         self.if_freq.setText(self.ifFreqv)
-        if self.fldigiv == 'Y':
-            self.fldigi.setChecked(True)
-            # change labels
-        else:
-            self.fldigi.setChecked(False)
-            # change labels
         if self.modev == 'Y':
             self.mode.setChecked(True)
         else:
@@ -468,25 +448,6 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         self.gqrxPortv = self.gqrxPort.text()
         self.hamlibIPv = self.hamlibIP.text()
         self.hamlibPortv = self.hamlibPort.text()
-        self.fldigiIPv = self.fldigiIP.text()
-        self.fldigiPortv = self.fldigiPort.text()
-        self.ifFreqv = self.if_freq.text()
-        if self.fldigi.isChecked():
-            self.fldigiv = 'Y'
-            # change labels
-            self.pushButton_6.setText('gqrx-->flrig')
-            self.pushButton_4.setText('gqrx<--flrig')
-            self.pushButton.setText('gqrx<-->flrig')
-            self.pushButton_2.setText('gqrx-->flrig')
-            self.pushButton_3.setText('gqrx<--flrig')
-        else:
-            self.fldigiv = 'N'
-            self.pushButton_6.setText('gqrx-->Hamlib')
-            self.pushButton_4.setText('gqrx<--Hamlib')
-            self.pushButton.setText('gqrx<-->Hamlib')
-            self.pushButton_2.setText('gqrx-->Hamlib')
-            self.pushButton_3.setText('gqrx<--Hamlib')
-            #change labels
         if self.mode.isChecked():
             self.modev = 'Y'
         else:
@@ -505,7 +466,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton_3.setStyleSheet("background-color: green")
             self.pushButton_4.setStyleSheet("background-color: green")
             self.pushButton_6.setStyleSheet("background-color: green")
-        configLine = self.gqrxIPv+','+self.gqrxPortv+','+self.hamlibIPv+','+self.hamlibPortv+','+self.fldigiIPv+','+self.fldigiPortv+','+self.fldigiv+','+self.modev+','+self.ifModev+','+self.ifFreqv
+        configLine = self.gqrxIPv+','+self.gqrxPortv+','+self.hamlibIPv+','+self.hamlibPortv+','+self.modev+','+self.ifModev+','+self.ifFreqv
         cf.write(configLine)
         cf.close()
         # revert to previous sync method
